#!/usr/bin/env node

const fs = require('fs');
const program = require('commander');
const download = require('download-git-repo');
const inquirer = require('inquirer');
const handlebars = require('handlebars');
const ora = require('ora');
const chalk = require('chalk');
const symbols = require('log-symbols');
const prompt = require('./lib/prompt');
const {
    VERSION,
    DOWN_PATH,
    TIPS,
    BIN,
    getMeta
} = require('./lib/config');
const spinner = ora(TIPS.init);

program.version(VERSION, BIN.version)
    .command(BIN.command)
    .action(name => {
        if (!fs.existsSync(name)) {
            const filed = prompt({name}).map(item => item.name);
            inquirer.prompt(prompt({name})).then(answers => {
                spinner.start();
                download(DOWN_PATH, name, {clone: true}, err => {
                    if (!err) {
                        spinner.succeed();
                        const fileName = `${name}/package.config.json`;
                        const outputName = `${name}/package.json`;
                        if (fs.existsSync(outputName)) {
                            const content = fs.readFileSync(fileName).toString();
                            const result = handlebars.compile(content)(getMeta(filed, answers));
                            fs.writeFileSync(outputName, result);
                            fs.unlinkSync(fileName);
                        }
                        console.log(symbols.success, chalk.green(TIPS.success));
                    }
                    else {
                        console.log(err);
                    }
                });
            });
        }
        else {
            console.log(symbols.error, chalk.red(TIPS.existence));
        }
    });
program.parse(process.argv);